@@ -5,12 +5,9 @@ fileStatus <- function(repo, testPath) {
   testStatus <- NULL
   
   # need to get top level path for repo
-  # try S4 call first, then S3
-  repoPath <- ifelse(isS4(repo),
-    try(repo@path, silent = TRUE),
-    try(repo$path, silent = TRUE))
+  repoPath <- try(repo$path, silent = TRUE)
   
-  if(class(repoPath) == "try-error") {
+  if( inherits(repoPath, "try-error") ) {
     return(infoNotFound())
   }
   
